---
feature_story: FS_69_15_45_21
feature_title: template instantiator
feature_status: TODO
---

# Motivation

The idea is to avoid copy-ing or symlink-ing static files from deployed Python packages.

Instead, pass control to template instantiators together with parameterizing data to generate those files.

# Principles

Template instantiator-s are meant to form a chain.

Each subsequent template instantiator is started by the previous one.

The very first template instantiator is the initial level of FS_28_84_41_40 multi-level bootstrap.

The contract (what data is being passed with what schema) can be unique
for each pair of (prev, next) template instantiators.

There is no pre-defined config (or any other input or output) files -
each template instantiator defines them by itself.

Why do we need that?

To standardize only the initial entry/exit point (FS_28_84_41_40 multi-level bootstrap),
maybe few subsequent ones (the further away, the less standard).
